@@ -10,8 +10,6 @@ from typing import Any, List
 
 root_dir = str(pathlib.Path.cwd().resolve())
 
-print("ROOT_DIR: " + root_dir)
-
 class Metric(ABC):
     def __init__(self, user, expected_value: int) -> None:
         self.result: Any = None
@@ -137,7 +135,7 @@ class Repository:
 
         subprocess.run(["rm", "-fr", root_dir + "/repo"])
         subprocess.run(["mkdir", root_dir + "/repo"])
-        subprocess.run(["git", "clone", self.url, root_dir + "/repo/"])
+        subprocess.run(["git", "clone", self.url, root_dir + "/repo/"], stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
 
     def get_repo(self) -> Repo:
         self.clone_repo_from_url()
